@@ -847,20 +847,6 @@ comsub(Expand *xp, char *cp)
 	if (t == NULL)
 		return XBASE;
 
-	if (t != NULL && t->type == TCOM && /* $(<file) */
-	    *t->args == NULL && *t->vars == NULL && t->ioact != NULL) {
-		struct ioword *io = *t->ioact;
-		char *name;
-
-		if ((io->flag&IOTYPE) != IOREAD)
-			errorf("funny $() command: %s",
-				snptreef((char *) 0, 32, "%R", io));
-		shf = shf_open(name = evalstr(io->name, DOTILDE), O_RDONLY, 0,
-			SHF_MAPHI|SHF_CLEXEC);
-		if (shf == NULL)
-			errorf("%s: cannot open $() input", name);
-		xp->split = 0;	/* no waitlast() */
-	} else {
 		int ofd1, pv[2];
 		openpipe(pv);
 		shf = shf_fdopen(pv[0], SHF_RD, (struct shf *) 0);
@@ -871,7 +857,6 @@ comsub(Expand *xp, char *cp)
 		restfd(1, ofd1);
 		startlast();
 		xp->split = 1;	/* waitlast() */
-	}
 
 	xp->u.shf = shf;
 	return XCOM;
