@@ -298,7 +298,7 @@ parse_args(argv, what, setargsp)
 	char *opts;
 	char *array = (char *) 0;
 	LameGetopt go;
-	int j, optc, set, arrayset = 0;
+	int j, optc, set;
 	unsigned int k;
 
 	/* First call?  Build option strings... */
@@ -390,19 +390,9 @@ parse_args(argv, what, setargsp)
 	}
 	if (setargsp)
 		/* -- means set $#/$* even if there are no arguments */
-		*setargsp = !arrayset && ((go.info & GI_MINUSMINUS)
+		*setargsp = ((go.info & GI_MINUSMINUS)
 					  || argv[go.optind]);
 
-	if (arrayset && (!*array || *skip_varname(array, FALSE))) {
-		bi_errorf("%s: is not an identifier", array);
-		return -1;
-	}
-	if (arrayset) {
-		set_array(array, arrayset, argv + go.optind);
-		for (; argv[go.optind]; go.optind++)
-			;
-	}
-
 	return go.optind;
 }
 
@@ -561,14 +551,6 @@ pat_scan(p, pe, match_sep)
 	return (const unsigned char *) 0;
 }
 
-
-int
-xstrcmp(p1, p2)
-	void *p1, *p2;
-{
-	return (strcmp((char *)p1, (char *)p2));
-}
-
 /* Initialize a Getopt structure */
 void
 ksh_getopt_reset(go, flags)
