@@ -1,5 +1,5 @@
 /* posh: src/builtins.c
-   Copyright (C) 2003, 2004  Clint Adams
+   Copyright (C) 2003, 2004, 2005, 2006  Clint Adams
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -260,8 +260,10 @@ int posh_builtin_dot(int UNUSED(argc), char UNUSED(**argv), int UNUSED(flags))
 	argv += optind;
 	argc -= optind;
 
-	if ((cp = *argv) == NULL)
-		return 0;
+	if ((cp = *argv) == NULL) {
+		bi_errorf("no file specified for sourcing");
+		return 1;
+	}
 	file = search(cp, path, R_OK, &err);
 	if (file == NULL) {
 		bi_errorf("%s: %s", cp, err ? strerror(err) : "not found");
@@ -535,7 +537,6 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 {
 	struct block *l = e->loc;
 	Tflag fset = 0, fclr = 0;
-	int local = 0;
 	char *fieldstr, *basestr;
 	int field, base, optc;
 	Tflag flag;
@@ -572,8 +573,6 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 		int i;
 		int rval = 0;
 
-		if (local)
-			fset |= LOCAL;
 		for (i = optind; argv[i]; i++) {
 			if (!typeset(argv[i], fset, fclr, field, base)) {
 				bi_errorf("%s: not identifier", argv[i]);
@@ -595,6 +594,26 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 	return 0;
 }
 
+int posh_builtin_local(int argc, char **argv, int UNUSED(flags))
+{
+char *p;
+
+	if(!argv[1])
+		return 1;
+
+        for (p = argv[1]; *p; p++) {
+		if (!isalnum(*p) && (*p!='_')) {
+			bi_errorf("%s: not identifier", argv[1]);
+			return 1;
+		}
+	}
+
+	if(!local(argv[1], 0)) {
+		bi_errorf("%s: error making local", argv[1]);
+		return 1;
+	}
+}
+
 int posh_builtin_eval(int argc, char **argv, int UNUSED(flags))
 {
 	struct source *s,*olds=source;
@@ -1329,6 +1348,7 @@ const struct builtin shbuiltins [] = {
  	{"export", posh_builtin_exportreadonlyset, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN | POSH_BUILTIN_EXPORT},
 	{"getopts", posh_builtin_getopts, POSH_BUILTIN_POSIX_REGULAR},
 	{"kill", posh_builtin_kill, POSH_BUILTIN_POSIX_REGULAR},
+	{"local", posh_builtin_local, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN},
 	{"pwd", posh_builtin_pwd, 0},
  	{"readonly", posh_builtin_exportreadonlyset, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN | POSH_BUILTIN_READONLY},
 	{NULL, NULL, 0}
